namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using System.Linq;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
	using Eco.Gameplay.Systems;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Mods.TechTree;
    using Eco.Shared.Items;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
	using Eco.Gameplay.Objects;
    
    [Serialized]
    [Weight(300)]                                          
    public partial class SeafoodGumboItem :
        FoodItem            
    {
        public override LocString DisplayName                     { get { return Localizer.DoStr("Seafood Gumbo"); } }
        public override LocString DisplayDescription                      { get { return Localizer.DoStr("A type of stew popular in the Southeast USA."); } }

        private static Nutrients nutrition = new Nutrients()    { Carbs = 10, Fat = 18, Protein = 7, Vitamins = 4};
        public override float Calories                          { get { return 800; } }
        public override Nutrients Nutrition                     { get { return nutrition; } }
    }

    [RequiresSkill(typeof(HomeCookingSkill), 3)]    
    public partial class SeafoodGumboRecipe : Recipe
    {
        public SeafoodGumboRecipe()
        {
            this.Products = new CraftingElement[]
            {
                new CraftingElement<SeafoodGumboItem>(),               
            };
            this.Ingredients = new CraftingElement[]
            {
                new CraftingElement<RawFishItem>(typeof(HomeCookingEfficiencySkill), 10, HomeCookingEfficiencySkill.MultiplicativeStrategy),
				new CraftingElement<RawSausageItem>(typeof(HomeCookingEfficiencySkill), 5, HomeCookingEfficiencySkill.MultiplicativeStrategy),
				new CraftingElement<RiceItem>(typeof(HomeCookingEfficiencySkill), 20, HomeCookingEfficiencySkill.MultiplicativeStrategy),
				new CraftingElement<CriminiMushroomsItem>(typeof(HomeCookingEfficiencySkill), 10, HomeCookingEfficiencySkill.MultiplicativeStrategy),
				new CraftingElement<FiddleheadsItem>(typeof(HomeCookingEfficiencySkill), 15, HomeCookingEfficiencySkill.MultiplicativeStrategy),
            };
            this.CraftMinutes = CreateCraftTimeValue(typeof(SeafoodGumboRecipe), Item.Get<SeafoodGumboItem>().UILink(), 8, typeof(HomeCookingSpeedSkill)); 
            this.Initialize(Localizer.DoStr("Seafood Gumbo"), typeof(SeafoodGumboRecipe));
            CraftingComponent.AddRecipe(typeof(CastIronStoveObject), this);
        }
    }
}